@@ -9,7 +9,7 @@ use JSON ();
 use B ();
 
 
-$VERSION = '1.12';
+$VERSION = '1.13';
 
 BEGIN {
     eval 'require Scalar::Util';
@@ -25,6 +25,13 @@ BEGIN {
         };
     }
 
+    if ($] < 5.006) {
+        eval q{
+            sub B::SVf_IOK () { 0x00010000; }
+            sub B::SVf_NOK () { 0x00020000; }
+        };
+    }
+
     $USE_UTF8 = JSON->USE_UTF8;
 
 }
@@ -197,7 +204,7 @@ sub _valueToJson {
         my $b_obj = B::svref_2object(\$value);  # for round trip problem
         # SvTYPE is IV or NV?
         return $value # as is 
-                if ($b_obj->FLAGS & 0x00010000 or $b_obj->FLAGS & 0x00020000);
+                if ($b_obj->FLAGS & B::SVf_IOK or $b_obj->FLAGS & B::SVf_NOK);
 
         return _stringfy($value);
     }
